from setuptools import setup

setup(name='zeblonk_probability',
      version='0.2',
      description='Gaussian and Binomial distributions',
      packages=['zeblonk_probability'],
      author = 'Jason Ho',
      author_emaikl = 'jason_c_ho@yahoo.com',
      zip_safe=False)
